@@ -1,20 +1,32 @@
-package Pcore::Whois v0.1.0;
+package Pcore::Whois v0.2.0;
 
-use Pcore qw[-class];
-use Pcore::Whois::Data;
-use Pcore::Whois::Server;
-use Pcore::Whois::Server::Response;
-use Const::Fast qw[const];
+use Pcore qw[-export -class -const];
 
 has max_threads => ( is => 'ro', isa => PositiveInt, default => 50 );
 has timeout     => ( is => 'ro', isa => PositiveInt, default => 30 );
+has proxy => ( is => 'ro', isa => InstanceOf ['Pcore::AE::Handle::ProxyPool'] );
 
 has threads => ( is => 'ro', default => 0, init_arg => undef );
 
 no Pcore;
 
+BEGIN {
+    our %EXPORT_TAGS = (    #
+        WHOIS_STATUS => [qw[$WHOIS_STATUS_OK $WHOIS_STATUS_NO_SERVER $WHOIS_STATUS_NETWORK $WHOIS_STATUS_BANNED]],
+    );
+}
+
 const our $NOT_AVAIL_DOMAIN => 'cwxtwtqcuduvo78hr0dbrfxpuhv8gmtm';
 
+const our $WHOIS_STATUS_OK        => 200;
+const our $WHOIS_STATUS_NO_SERVER => 404;
+const our $WHOIS_STATUS_NETWORK   => 500;
+const our $WHOIS_STATUS_BANNED    => 501;
+
+use Pcore::Whois::Data;
+use Pcore::Whois::Server;
+use Pcore::Whois::Server::Response;
+
 sub whois ( $self, $domain, $cb ) {
     state $cb_cache = {};
 
@@ -68,7 +80,7 @@ sub _run_thread ( $self, $domain, $cb ) {
             if ( !$server ) {
                 my $res = Pcore::Whois::Server::Response->new(
                     {   query  => $domain->name,
-                        status => 500,
+                        status => $WHOIS_STATUS_NO_SERVER,
                         reason => 'WHOIS server is not available',
                     }
                 );
@@ -79,6 +91,7 @@ sub _run_thread ( $self, $domain, $cb ) {
                 $server->request(
                     $domain->name,
                     timeout => $self->timeout,
+                    proxy   => $self->{proxy},
                     sub ($res) {
                         $cb->( $domain, $res );
 
